| namcs2019sv | R Documentation |
Selected variables from a data system of visits to office-based physicians. Note that the unit of observation is visits, not patients - this distinction is important since a single patient can make multiple visits.
namcs2019sv
namcs2019sv_df
An object of class survey.design2 (inherits from survey.design) with 8250 rows and 33 columns.
An object of class data.frame with 8250 rows and 33 columns.
namcs2019sv_df is a data frame.
namcs2019sv is a survey object created from namcs2019sv_df
using survey::svydesign().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.