NHIS is a national survey that monitors the health of the U.S. population. This survey object contains selected variables and is limited to observations on individuals aged 18+ only.
Format
An object of class survey.design2 (inherits from survey.design) with 32577 rows and 12 columns.
Data ("Sample adult interview"): https://www.cdc.gov/nchs/nhis/documentation/2024-nhis.html