Skip to contents

Population counts for use in examples.

Usage

uspop_example

Format

An object of class list of length 9.

Details

Most of the list elements are population estimates of the civilian non-institutional population of the United States as of July 1, 2019. Used for calculating rates based on namcs2019sv. For usage examples, see tab_rate() and tab_subset_rate().

$age_group_std* is population counts for adults aged 18 and older, by age group, from the 2000 US Standard Population as published by the U.S. Census Bureau. Used as the reference population for age-standardization of survey estimates based on nhis2024a. For usage examples, see set_survey().

Examples

names(uspop_example)
#> [1] "total"              "MSA"                "AGER"              
#> [4] "Age group"          "SEX"                "AGER x SEX"        
#> [7] "Age group 5"        "age_group_std"      "age_group_std_prop"