Selected variables from the National Ambulatory Medical Care Survey (NAMCS) 2019 Public Use File (PUF)
Source:R/z_data.R
namcs2019sv.RdSelected variables from a data system of visits to office-based physicians. Note that the unit of observation is visits, not patients - this distinction is important since a single patient can make multiple visits.
Format
An object of class survey.design2 (inherits from survey.design) with 8250 rows and 33 columns.
An object of class data.frame with 8250 rows and 33 columns.
Details
namcs2019sv_df is a data frame.
namcs2019sv is a survey object created from namcs2019sv_df
using survey::svydesign().