| restructure | R Documentation |
Restructure the output of the tabulation functions to make it more structured and easier to process programmatically.
restructure(tab_output, lvls = c())
tab_output |
output from a tabulation function. An object of class
|
lvls |
(optional) only show these levels. |
Also see as.data.frame.astra_table() and set_opts(raw = TRUE).
data.frame
Other print:
as.data.frame.astra_table(),
print.astra_table(),
set_opts()
set_survey(namcs2019sv, mode = "nchs")
## total() |> restructure()
restructure( total() )
## tab_subset("MAJOR", "AGER") |> restructure(lvls = c("Pre-surgery", "Post-surgery"))
mytables = tab_subset("MAJOR", "AGER")
restructure(mytables, lvls = c("Pre-surgery", "Post-surgery"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.